Trait layered_bitset::BitSet [−][src]
pub trait BitSet {
const UPPER_BOUND: u32;
fn get(&self, index: u32) -> bool;
fn find_set(&self, lower_bound: u32) -> Option<u32>;
fn is_empty(&self) -> bool { ... }
}Expand description
Common trait for all bitsets in bitseto crate.
Associated Constants
const UPPER_BOUND: u32
const UPPER_BOUND: u32Upper bound for this bitset indices.
Implementation is expected to panic if index equal to or greter than UPPER_BOUND is speicifed.
Required methods
Returns bit state at specified index.
Panics
This function may panic if index is equal to or greter than UPPER_BOUND.