BitSetMut

Trait BitSetMut 

pub trait BitSetMut: BitSet {
    // Required method
    fn set(&mut self, index: u32, bit: bool);
}
👎Deprecated:

use bitsetium crate instead

Common trait for all mutable bitsets in bitseto crate.

Required Methods

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Sets bit state at specified index.

Panics

This function may panic if index is equal to or greter than UPPER_BOUND.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BitSetMut for u8

Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Source

impl BitSetMut for u16

Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Source

impl BitSetMut for u32

Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Source

impl BitSetMut for u64

Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Source

impl BitSetMut for u128

Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Source

impl<T> BitSetMut for &mut T
where T: BitSetMut,

Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Source

impl<T> BitSetMut for Box<T>
where T: BitSetMut,

Available on crate feature alloc only.
Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Source

impl<T> BitSetMut for Option<T>
where T: BitSetMut + Default,

Source

fn set(&mut self, index: u32, bit: bool)

👎Deprecated:

use bitsetium crate instead

Implementors

Source

impl<T, B, const N: usize> BitSetMut for Layered<T, B, N>
where T: BitSetMut, B: BitSetMut,